@@ -1,5 +1,7 @@
+import sys
 from argparse import RawTextHelpFormatter
 import binascii
+import six
 
 from fa.commands import find_bytes
 
@@ -35,7 +37,11 @@ def find_str(string, null_terminated=False):
 
 
 def run(segments, args, addresses, interpreter=None, **kwargs):
-    hex_str = binascii.hexlify(args.hex_str)
+    hex_str = binascii.hexlify(six.b(args.hex_str))
+    
+    if sys.version[0] == '3':
+        hex_str = hex_str.decode()
+    
     if args.null_terminated:
         hex_str += '00'
     setattr(args, 'hex_str', hex_str)
