@@ -1,5 +1,4 @@
 from fa.utils import ArgumentParserNoExit
-from fa import context
 
 try:
     import idc
@@ -9,17 +8,16 @@ except ImportError:
 
 def get_parser():
     p = ArgumentParserNoExit('set-name',
-                             description='set name in disassembler')
+                             description='set symbol name')
     p.add_argument('name')
     return p
 
 
-@context.ida_context
-def set_name(addresses, name):
+def set_name(addresses, name, interpreter):
     for ea in addresses:
-        idc.set_name(ea, name, idc.SN_CHECK)
+        interpreter.set_symbol(name, ea)
     return addresses
 
 
 def run(segments, args, addresses, interpreter=None, **kwargs):
-    return set_name(addresses, args.name)
+    return set_name(addresses, args.name, interpreter)
