@@ -1,17 +1,12 @@
 from argparse import RawTextHelpFormatter
 from fa import utils
 
-DESCRIPTION = '''verifies the result-list contains a single value
+DESCRIPTION = '''make the resultset unique
 
-EXAMPLE #1:
-    results = [4, 12, 0, 8]
+EXAMPLE:
+    results = [0, 4, 8, 8, 12]
     -> unique
-    result = []
-
-EXAMPLE #2:
-    results = [4]
-    -> unique
-    result = [4]
+    result = [0, 4, 8, 12]
 '''
 
 
@@ -22,9 +17,5 @@ def get_parser():
     return p
 
 
-def unique(addresses):
-    return addresses if len(addresses) == 1 else []
-
-
 def run(segments, args, addresses, interpreter=None, **kwargs):
-    return unique(addresses)
+    return list(set(addresses))
