@@ -243,6 +243,10 @@ class IdaLoader(fainterp.FaInterp):
 
         return results
 
+    def set_symbol(self, symbol_name, value):
+        super(IdaLoader, self).set_symbol(symbol_name, value)
+        idc.set_name(value, symbol_name, idc.SN_CHECK)
+
     def symbols(self, output_file_path=None):
         """
         Run find for all SIG files in currently active project.
@@ -255,10 +259,13 @@ class IdaLoader(fainterp.FaInterp):
 
         try:
             ida_kernwin.show_wait_box('Searching...')
-            super(IdaLoader, self).symbols(output_file_path=output_file_path)
+            results = super(IdaLoader, self).symbols()
 
             ida_kernwin.replace_wait_box('Extracting...')
-            results = IdaLoader.extract_all_user_names(output_file_path)
+            ida_symbols = IdaLoader.extract_all_user_names(output_file_path)
+
+            results.update(ida_symbols)
+
         except Exception as e:
             traceback.print_exc()
         finally:
@@ -356,7 +363,7 @@ class IdaLoader(fainterp.FaInterp):
         :return: None
         """
         class SettingsForm(Form):
-            def __init__(self, signatures_root):
+            def __init__(self, signatures_root, use_template):
                 description = '''
                 <h2>Settings</h2>
                 <div>
@@ -366,7 +373,7 @@ class IdaLoader(fainterp.FaInterp):
                     <a href="https://github.com/doronz88/fa">
                     For more info</a>
                 </div>
-                '''.format(signatures_root)
+                '''
 
                 Form.__init__(self,
                               r"""BUTTON YES* Save
@@ -388,14 +395,14 @@ class IdaLoader(fainterp.FaInterp):
                                           items=['Default',
                                                  'Using function bytes'],
                                           readonly=True,
-                                          selval=0),
+                                          selval=use_template),
                               })
                 self.__n = 0
 
             def OnFormChange(self, fid):
                 return 1
 
-        f = SettingsForm(self._signatures_root)
+        f = SettingsForm(self._signatures_root, self._create_template_symbol)
         f, args = f.Compile()
         ok = f.Execute()
         if ok == 1:
